@@ -1,14 +1,5 @@
-import pandas as pd
 import numpy as np
-import time
-import random
-import warnings
-import math
-import itertools as it
 
-from ..DataSet import DataSet
-from ..BioNetwork import BioNetwork
-from .._clustering.clusterobj import clusterObj
 from .._clustering import similarities as sim
 
 def dunnsindex(clusterObj):
